==> nextcloud-app-news-1%3A25.2.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/th.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "คำขอล้มเหลว ไม่มีการเชื่อมต่อเครือข่าย!",
    "Request unauthorized. Are you logged in?" : "คำขอไม่ได้รับอนุญาต คุณเข้าสู่ระบบอยู่หรือเปล่า?",
    "Token expired or app not enabled! Reload the page!" : "โทเค็นหมดอายุหรือไม่ได้เปิดใช้งานแอป! กรุณาโหลดหน้าใหม่!",
    "Unread articles" : "บทความที่ยังไม่ได้อ่าน",
    "Download" : "ดาวน์โหลด",
    "Close" : "ปิด",
    "Web address" : "ที่อยู่เว็บ",
    "No folder" : "ไม่มีโฟลเดอร์",
    "Folder name" : "ชื่อโฟลเดอร์",
    "Username" : "ชื่อผู้ใช้",
    "Password" : "รหัสผ่าน",
    "Feed exists already!" : "ฟีดมีอยู่แล้ว!",
    "New folder" : "โฟลเดอร์ใหม่",
    "Folder exists already!" : "โฟลเดอร์มีอยู่แล้ว!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "ข้อมูลประจำตัวการตรวจสอบสิทธิ์พื้นฐานของ HTTP จะต้องเก็บไว้แบบไม่เข้ารหัส! ทุกคนที่มีการเข้าถึงเซิร์ฟเวอร์หรือฐานข้อมูลจะสามารถเข้าถึงมันได้!",
    "Credentials" : "ข้อมูลประจำตัว",
    "Subscribe" : "สมัครรับข้อมูล",
    "Maximum read count per feed" : "จำนวนอ่านสูงสุดต่อฟีด",
    "Maximum redirects" : "เปลี่ยนเส้นทางสูงสุด",
    "Feed fetcher timeout" : "ตัวเรียกฟีดหมดเวลา",
    "Explore Service URL" : "URL บริการสำรวจ",
    "Move" : "ย้าย",
    "Share" : "แชร์",
    "All articles" : "บทความทั้งหมด",
    "Starred" : "ติดดาวแล้ว",
    "Explore" : "สำรวจ",
    "Settings" : "การตั้งค่า",
    "Documentation" : "เอกสารประกอบ",
    "Keyboard shortcuts" : "แป้นพิมพ์ลัด",
    "Disable mark read through scrolling" : "ปิดการทำเป็นอ่านแล้วขณะเลื่อนผ่าน",
    "Show all articles" : "แสดงบทความทั้งหมด",
    "Reverse ordering (oldest on top)" : "เรียงในลำดับย้อนกลับ (เก่าสุดอยู่ด้านบน)",
    "Rename" : "เปลี่ยนชื่อ",
    "Delete" : "ลบ",
    "Rename Feed" : "เปลี่ยนชื่อฟีด",
    "Newest first" : "ใหม่ที่สุดก่อน",
    "Oldest first" : "เก่าที่สุดก่อน",
    "Previous" : "ก่อนหน้า",
    "Next" : "ถัดไป",
    "Toggle star article" : "สลับการติดดาวบทความ",
    "by" : "โดย",
    "from" : "จาก",
    "Play audio" : "เล่นเสียง",
    "Download audio" : "ดาวน์โหลดเสียง",
    "Download video" : "ดาวน์โหลดวิดีโอ",
    "Open website" : "เปิดเว็บไซต์",
    "Keep article unread" : "ตั้งเป็นบทความยังไม่ได้อ่าน",
    "Toggle keep current article unread" : "สลับให้บทความในปัจจุบันยังไม่ได้อ่าน",
    "Remove keep article unread" : "การลบคงสถานะบทความยังไม่ได้อ่าน",
    "{num} years ago" : "{num}ปีที่แล้ว",
    "Keyboard shortcut" : "แป้นพิมพ์ลัด",
    "Jump to next article" : "ข้ามไปยังบทความถัดไป",
    "Jump to previous article" : "ข้ามไปยังบทความก่อนหน้า",
    "right" : "ขวา",
    "left" : "ซ้าย",
    "Star article and jump to next one" : "ติดดาวบทความและข้ามไปบทความถัดไป",
    "Open article in new tab" : "เปิดบทความในแท็บใหม่",
    "Refresh" : "รีเฟรช",
    "Load next feed" : "โหลดฟีดถัดไป",
    "Load previous feed" : "โหลดฟีดก่อนหน้า",
    "Load previous folder" : "โหลดโฟลเดอร์ก่อนหน้า",
    "Load next folder" : "โหลดโฟลเดอร์ถัดไป",
    "Scroll to active navigation entry" : "เลื่อนไปยังรายการนำทางที่ใช้อยู่",
    "How to set up the operating system cron" : "วิธีการตั้งค่า cron ของระบบปฏิบัติการ",
    "Install and set up a faster parallel updater that uses the News app's update API" : "ติดตั้งและตั้งค่าตัวอัปเดตขนานที่เร็วขึ้น ซึ่งใช้ API การอัปเดตของแอปข่าว",
    "No articles available" : "ไม่มีบทความที่อ่านได้",
    "No unread articles available" : "ไม่มีบทความที่ยังไม่ได้อ่าน",
    "Star article" : "ติดดาวบทความ",
    "Unstar article" : "เลิกติดดาวบทความ",
    "Description" : "คำอธิบาย",
    "Toggle expand article in compact view" : "สลับการขยายบทความในมุมมองแบบย่อ",
    "Mark current article's feed/folder read" : "ทำฟีด/โฟลเดอร์ของบทความปัจจุบันเป็นอ่านแล้ว",
    "Folder" : "โฟลเดอร์",
    "Go back" : "กลับไป",
    "New Folder" : "โฟลเดอร์ใหม่",
    "Create" : "สร้าง",
    "Update failed more than 50 times" : "อัปเดตล้มเหลวมากกว่า 50 ครั้ง",
    "Deleted feed" : "ฟีดที่ถูกลบ",
    "Undo delete feed" : "เลิกทำการลบฟีด",
    "Menu" : "เมนู",
    "Dismiss" : "ปิดทิ้ง",
    "Collapse" : "ย่อ",
    "Deleted folder" : "โฟลเดอร์ที่ถูกลบ",
    "Undo delete folder" : "เลิกทำการลบโฟลเดอร์",
    "Compact view" : "มุมมองแบบย่อ",
    "Expand articles on key navigation" : "ขยายบทความขณะนำทางด้วยแป้น",
    "Subscriptions (OPML)" : "การสมัครใช้งาน (OPML)",
    "Import" : "นำเข้า",
    "Export" : "ส่งออก",
    "Error when importing: OPML is does neither contain feeds nor folders" : "ข้อผิดพลาดขณะนำเข้า: OPML ไม่มีฟีดหรือโฟลเดอร์",
    "Unread/Starred Articles" : "บทความที่ยังไม่ได้อ่าน/ติดดาว",
    "Error when importing: file does not contain valid JSON" : "ข้อผิดพลาดขณะนำเข้า: ไฟล์ไม่มี JSON ที่ถูกต้อง",
    "Help" : "ช่วยเหลือ",
    "Report a bug" : "รายงานข้อผิดพลาด"
},
"nplurals=1; plural=0;");

==> nextcloud-app-news-1%3A26.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/th.js <==
OC.L10N.register(
    "news",
    {
    "Unread articles" : "บทความที่ยังไม่ได้อ่าน",
    "Download" : "ดาวน์โหลด",
    "Close" : "ปิด",
    "Web address" : "ที่อยู่เว็บ",
    "No folder" : "ไม่มีโฟลเดอร์",
    "Folder name" : "ชื่อโฟลเดอร์",
    "Username" : "ชื่อผู้ใช้",
    "Password" : "รหัสผ่าน",
    "Feed exists already!" : "ฟีดมีอยู่แล้ว!",
    "New folder" : "โฟลเดอร์ใหม่",
    "Folder exists already!" : "โฟลเดอร์มีอยู่แล้ว!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "ข้อมูลประจำตัวการตรวจสอบสิทธิ์พื้นฐานของ HTTP จะต้องเก็บไว้แบบไม่เข้ารหัส! ทุกคนที่มีการเข้าถึงเซิร์ฟเวอร์หรือฐานข้อมูลจะสามารถเข้าถึงมันได้!",
    "Credentials" : "ข้อมูลประจำตัว",
    "Subscribe" : "สมัครรับข้อมูล",
    "Maximum read count per feed" : "จำนวนอ่านสูงสุดต่อฟีด",
    "Maximum redirects" : "เปลี่ยนเส้นทางสูงสุด",
    "Feed fetcher timeout" : "ตัวเรียกฟีดหมดเวลา",
    "Explore Service URL" : "URL บริการสำรวจ",
    "Move" : "ย้าย",
    "Share" : "แชร์",
    "All articles" : "บทความทั้งหมด",
    "Starred" : "ติดดาวแล้ว",
    "Explore" : "สำรวจ",
    "Settings" : "การตั้งค่า",
    "Documentation" : "เอกสารประกอบ",
    "Keyboard shortcuts" : "แป้นพิมพ์ลัด",
    "Disable mark read through scrolling" : "ปิดการทำเป็นอ่านแล้วขณะเลื่อนผ่าน",
    "Show all articles" : "แสดงบทความทั้งหมด",
    "Reverse ordering (oldest on top)" : "เรียงในลำดับย้อนกลับ (เก่าสุดอยู่ด้านบน)",
    "Rename" : "เปลี่ยนชื่อ",
    "Delete" : "ลบ",
    "Rename Feed" : "เปลี่ยนชื่อฟีด",
    "Newest first" : "ใหม่ที่สุดก่อน",
    "Oldest first" : "เก่าที่สุดก่อน",
    "Previous" : "ก่อนหน้า",
    "Next" : "ถัดไป",
    "Toggle star article" : "สลับการติดดาวบทความ",
    "by" : "โดย",
    "Play audio" : "เล่นเสียง",
    "Download audio" : "ดาวน์โหลดเสียง",
    "Download video" : "ดาวน์โหลดวิดีโอ",
    "Open website" : "เปิดเว็บไซต์",
    "Keep article unread" : "ตั้งเป็นบทความยังไม่ได้อ่าน",
    "Toggle keep current article unread" : "สลับให้บทความในปัจจุบันยังไม่ได้อ่าน",
    "Remove keep article unread" : "การลบคงสถานะบทความยังไม่ได้อ่าน",
    "Please wait" : "โปรดรอ",
    "Keyboard shortcut" : "แป้นพิมพ์ลัด",
    "Jump to next article" : "ข้ามไปยังบทความถัดไป",
    "Jump to previous article" : "ข้ามไปยังบทความก่อนหน้า",
    "right" : "ขวา",
    "left" : "ซ้าย",
    "Star article and jump to next one" : "ติดดาวบทความและข้ามไปบทความถัดไป",
    "Open article in new tab" : "เปิดบทความในแท็บใหม่",
    "Refresh" : "รีเฟรช",
    "Load next feed" : "โหลดฟีดถัดไป",
    "Load previous feed" : "โหลดฟีดก่อนหน้า",
    "Load previous folder" : "โหลดโฟลเดอร์ก่อนหน้า",
    "Load next folder" : "โหลดโฟลเดอร์ถัดไป",
    "Scroll to active navigation entry" : "เลื่อนไปยังรายการนำทางที่ใช้อยู่",
    "How to set up the operating system cron" : "วิธีการตั้งค่า cron ของระบบปฏิบัติการ",
    "Install and set up a faster parallel updater that uses the News app's update API" : "ติดตั้งและตั้งค่าตัวอัปเดตขนานที่เร็วขึ้น ซึ่งใช้ API การอัปเดตของแอปข่าว"
},
"nplurals=1; plural=0;");
